dim gws, gfs 
set gws = CreateObject("Wscript.Shell")
set gfs = CreateObject("Scripting.FileSystemObject")

FLD_TLBHOME = gfs.buildPath(gws.ExpandEnvironmentStrings("%PROGRAMFILES%"), "TrueLaunchBar")
FLD_TLBSKINS = gfs.buildPath(FLD_TLBHOME, "skins")

FLD_HOME = gfs.getParentFolderName(wscript.scriptFullName) 
FLD_COLORS = gfs.buildPath(FLD_HOME, "Colors")
FLD_PALETTES = gfs.buildPath(FLD_HOME, "Palettes")
FLD_STYLES = gfs.buildPath(FLD_HOME, "Styles")
FLD_ICONS = gfs.buildPath(FLD_HOME, "Icons")

F_NOICON = gfs.buildPath(FLD_HOME, "noicon.png")

' Hotkeys
HK_REFRESH = "^{F5}"          ' CTRL+F5


function new_CFile(pFile)

    set new_CFile = new CFile
    new_CFile.fullpath = pFile

end function 

class CFile

    public fullpath

    public function folder
        folder = gfs.getParentFolderName(fullPath)
    end function

    public function parentFolder
        parentFolder = gfs.getParentFolderName(folder)
    end function
    	
    public function foldername
        folderName = gfs.getBaseName(folder)
    end function    
  
    public function filename
        fileName = gfs.getFileName(fullPath)
    end function

    public function name
        name = gfs.getBaseName(fullPath)
    end function

    public function extension
        extension = gfs.getExtensionName(fullPath)
    end function

  
    public function toString

        toString =  "name: " & name & vbcrlf & _
                    "filename: " & filename & vbcrlf & _
                    "folder: " & folder & vbcrlf & _
                    "extension: " & extension & vbcrlf & _
                    "foldername: " & foldername & vbcrlf & _
                    "fullpath: " & fullpath

    end function 'toString

    public sub show
    
        msgbox toString, vbInformation, "CFile" 
        
    end sub 'show
       

    public function rename(pNewName)
    
        set rename = new_CFile(gfs.buildPath(folder, pNewName))
        
    end function 'rename

    public function exists
    
        fileExists = gfs.fileExists(fullPath)
        folderExists = gfs.folderExists(fullPath)
        
        exists = fileExists OR folderExists
        
    end function    
   
end class 'CFile    

function new_CResFile(pFile)

    set new_CResFile = new CResFile
    new_CResFile.fullpath = pFile

end function 

class CResFile

    public fullpath

    public function folder
        folder = gfs.getParentFolderName(fullPath)
    end function

    public function parentFolder
        parentFolder = gfs.getParentFolderName(folder)
    end function
    	
    public function foldername
        folderName = gfs.getBaseName(folder)
    end function    
  
    public function filename
        fileName = gfs.getFileName(fullPath)
    end function

    public function name
        name = gfs.getBaseName(fullPath)
    end function

    public function extension
		extension = split(gfs.getExtensionName(fullPath), ",")(0)
    end function

	public function resIndex
		dim splitExtension
		
		splitExtension = split(gfs.getExtensionName(fullPath), ",")
		if ubound(splitExtension) = 1 then
			resIndex = splitExtension(1)
		else
			resIndex = null
		end if	
	end function
  
    public function toString

        toString =  "name: " & name & vbcrlf & _
                    "filename: " & filename & vbcrlf & _
                    "folder: " & folder & vbcrlf & _
                    "extension: " & extension & vbcrlf & _
                    "resIndex: " & resIndex & vbcrlf & _
                    "foldername: " & foldername & vbcrlf & _
                    "fullpath: " & fullpath

    end function 'toString

    public sub show
    
        msgbox toString, vbInformation, "CResFile" 
        
    end sub 'show
       

    public function rename(pNewName)
    
        set rename = new_CResFile(gfs.buildPath(folder, pNewName))
        
    end function 'rename

    public function exists
    
        fileExists = gfs.fileExists(fullPath)
        folderExists = gfs.folderExists(fullPath)
        
        exists = fileExists OR folderExists
        
    end function    
   
end class 'CResFile    



'**** INCLUDED FILE: classes\_CToolbar.vbs ****

'#USES classes\_CMenu.vbs
'#USES classes\_CItem.vbs
'**** INCLUDED FILE: classes\_CINIFile.vbs ****
class CINIFile

    public aFile
    private lastIndex
    
    sub load(pINIFile)

        set fs = createObject("Scripting.FileSystemObject")    
        set file = fs.openTextFile( pINIFile, 1, True )
		if not file.atendofstream then
			aFile = split(file.readAll(), vbCRLF)    
		end if		
		file.close
        
    end sub

    sub save(pINIFile)

        set fs = createObject("Scripting.FileSystemObject")    
        set file = fs.openTextFile(pINIFile, 2, false)
        sFile = join(aFile, vbCRLF)
        file.write(sFile)
        file.close
        
    end sub


    function getKeyValue(pSection, pKey)
    
        index = findKey(pSection, pKey)
        
        splitLine = split(aFile(index), "=")
        getKeyValue = ""
        if lcase(trim(splitLine(0))) = lcase(trim(pKey)) then
            getKeyValue = splitLine(1)
        end if    

    end function 'getKeyValue

    
    function findKey(pSection, pKey)

        ' returns the line number of the found key, 0 if the keys does not exist
        ' and -1 if the section does not exist.
        
        ret = 0
        sectionFound = false
        index = -1
        for each line in aFile
            
            index = index + 1    
            trimmedLine = trim(line)             
            
            if NOT sectionFound then
          
                if replace(lcase(trimmedLine), lcase(pSection), "") = "[]" then
                    sectionFound = true
                end if    

            else
                
                if left(trimmedLine, 1) = "[" then
                    exit for
                else
                    splitLine = split(trimmedLine, "=")
                    
                    if ubound(splitLine) > -1 then
                        if lcase(trim(splitLine(0))) = lcase(pKey) then
                            ret = index
                            exit for
                        end if    
                    end if
                end if
            end if

        next

        lastIndex = index

        if not sectionFound then
            ret = -1
        end if    
            
        findKey = ret

    end function

    sub setKeyValue(pSection, pKey, pValue)
    
        index = findKey(pSection, pKey)
        if index > 0 then 
            splitLine = split(aFile(index), "=")
            if lcase(trim(splitLine(0))) = lcase(trim(pKey)) then
                aFile(index) = splitLine(0) & "=" & pValue
            end if
        else
       
            if index = -1 then
                ubnd = ubound(aFile) + 2
                redim preserve aFile(ubnd)
                aFile(ubnd-1) = "[" & pSection & "]"
                aFile(ubnd) = pKey & "=" & pValue
                
            else 
                ubnd = ubound(aFile)
                redim preserve aFile(ubnd + 1)
                for i = ubnd to lastIndex + 1 step -1
                    aFile(i+1) = aFile(i) 
                next
                aFile(lastIndex+1) = pKey & "=" & pValue
            end if   
                
        end if            
    
    end sub 'setKeyValue

    
    public function findSections(pSection)
    
        set findSections = CreateObject("Scripting.Dictionary")
        
        for each line in aFile
            trimmedLine = trim(line)
            if left(trimmedLine, len(pSection) + 1) = "[" & pSection then
                findSections.add mid(trimmedLine, 2, len(trimmedLine) - 2), ""
            end if
        next        

    end function
    
    function getSection(pSection)
    
        set getSection = createObject("Scripting.Dictionary")
        
        start = false
        for each line in aFile
            trimmedLine = trim(line)
            if start then
                if left(trimmedLine, 1) = "[" then
                    exit for
                end if
                if not trimmedLine = "" then
                    splitLine = split(trimmedLine, "=")
                    getSection.add splitLine(0), splitLine(1)
                 end if   
            end if
            if trimmedLine = "[" & pSection & "]" then
                start = true
            end if
        next
        
    end function

    
    public function nextSectionInstance(pSection)
    
        set sections = findSections(pSection)
        nextInstance = 0
        for each section in sections
            instance = replace(section, pSection, "")
            if isNumeric(instance) then
                if instance > nextInstance then
                    nextInstance = instance + 1
                end if
            end if
        next

        nextSectionInstance = pSection & nextInstance

                        
    end function    
              
    
    
    private sub Class_Initialize
        lastIndex = 0
		aFile = array()
    end sub

    
end class 'CINIFile


'**** END INCLUDED FILE: classes\_CINIFile.vbs ****

'#USES classes\_CWorkSpace.vbs



function new_CToolbar(pPath)

    set this = new CToolbar
    this.folder = pPath
    this.name = gfs.getBaseName(this.folder)
    this.tlbdata = gfs.buildPath(this.folder, "tlbdata.xml")
    this.setup = gfs.buildPath(this.folder, "setup.ini")
    this.images = gfs.buildPath(this.folder, "~~images~~")
    this.btnImages = gfs.buildPath(this.images, "btnimages")
    this.icons = gfs.buildPath(this.images, "icons")
    this.overlays = gfs.buildPath(this.images, "overlays") 
    set new_CToolbar = this

end function 'new_CToolbar

class CToolbar

    public name
    public folder
    public tlbdata
    public setup
    public images
    public btnImages
    public icons
    public overlays

    public function toString

        toString =  "name: " & name & vbcrlf & _
                    "folder: " & folder & vbcrlf & _
                    "tlbdata: " & tlbdata & vbcrlf & _
                    "setup: " & setup & vbcrlf & _
                    "images: " & images & vbcrlf & _
                    "btnImages: " & btnImages & vbcrlf & _
                    "icons: " & icons & vbcrlf & _
                    "overlays: " & overlays

    end function 'toString

    public sub show(pInstanceName)
    
        msgbox toString, vbInformation, pInstanceName & " (instance of CToolbar)" 
        
    end sub 'show

 
end class 'CToolbar    
    
'**** END INCLUDED FILE: classes\_CToolbar.vbs ****

'**** INCLUDED FILE: classes\_CTLBFolder.vbs ****

'**** INCLUDED FILE: classes\_CTLBData.vbs ****

'**** INCLUDED FILE: classes\_CFolder.vbs ****


function new_CFolder(pFile)

    set new_CFolder = new CFolder
    new_CFolder.path = pFile

end function 'create


class CFolder

    public path

    public function name
        name = gfs.getBaseName(path)
    end function
    
    public sub write

        wscript.echo(toString)
        
    end sub 'write
    
    public function toString

        toString =  "name: " & name & vbcrlf & _
                    "path: " & path

    end function 'toString

    
    public function exists
    
        exists = gfs.folderExists(fullPath)
        
    end function    

    
    public sub create
    
        gfs.createFolder(path)
    
    end sub
 
   
end class 'CFolder    
'**** END INCLUDED FILE: classes\_CFolder.vbs ****



public function new_CTLBData(ptlbdata)

        set new_CTLBData = new CTLBData  

        new_CTLBData.xmlDoc.loadXML("<?xml version=""1.0"" encoding=""utf-8""?>" & vbCRLF & _
            "<tlbdata>" & vbCRLF & _
            "    <folder name="""">" & vbCRLF & _
            "        <layout>" & vbCRLF & _
            "        </layout>" & vbCRLF & _
            "        <options skin="""" fontNameMI="""" fontSizeCAP=""0"" fontNameCAP="""" fontSizeTIT=""0"" fontNameTIT="""" disableGlass=""0"" disableTips=""0"" overlayFileName="""" overlayFlags=""34"" overlayTransparency=""255"" filterShowMask="""" filterHideMask=""""/>" & vbCRLF & _
            "    </folder>" & vbCRLF & _
            "</tlbdata>")        

        set new_CTLBData.options=new_CTLBData.xmlDoc.selectSingleNode("tlbdata/folder/options")     
      
        new_CTLBData.xmlDocPath = ptlbdata
            
end function


public function load_CTLBData(ptlbdata) 

    set load_CTLBData = new CTLBData
    load_CTLBData.load(ptlbdata)         
    load_CTLBData.xmlDocPath = ptlbdata
     
end function  
    

    

class CTLBData

    public function newItem(pName)
    
        set element = xmlDoc.createElement("item")
        element.setAttribute "name", pName    

        set newItem = element    

    end function
    
'   ** Public Methods

    public sub save
		on error resume next
        xmlDoc.save(xmlDocPath)
		on error goto 0
    end sub

    public sub saveAs(pFile)
		on error resume next
        xmlDoc.save(pFile)
		on error goto 0
    end sub
    
  
    function findItemByName(pItemName)
        set findItemByName=xmlDoc.selectSingleNode("//layout/item[@name='" & pItemName & "']")        
    end function

   
    public function getChildText(pItemNode, pElementName)
        
        getChildText = ""
		if not pItemNode is nothing then
			for each node in pItemNode.childNodes
				if node.nodeName = pElementName then
					getChildText = node.text
				end if
			next           
        end if
		
    end function
        

    public sub removeChild(pItemNode, pChildName)

        set childNodes = pItemNode.childNodes
         
        for each childNode in childNodes 
            if childNode.nodeName = pChildName then
                pItemNode.removeChild(childNode)
            end if     
        next
   
    end sub
        

    public sub load(ptlbdata) 

        dim	counter
		counter = 0
		do while not xmlDoc.Load(ptlbdata) and counter < 1000
			wscript.sleep 50
			counter = counter + 50
		loop	
        xmlDocPath = ptlbdata
         
    end sub  
    
'   ** Public Properties
    
    public xmlDoc
    public xmlDocPath
    
'   ** Private Methods

    private sub Class_Initialize()
    
        set xmlDoc = createObject("Microsoft.XMLDOM")
        xmlDoc.Async = false
        xmlDoc.setProperty "SelectionLanguage", "XPath"
        
    end sub

    public function addNodes(pXMLElement, pText)

        set itemNodes = xmlDoc.selectNodes("//layout/item[contains(@name, '.lnk')]")

        for each node in itemNodes
			set childNodes = node.childNodes
			found = false
			for each childNode in childNodes 
				if childNode.nodeName = pXMLElement then
					found = true
				end if     
			next
			if not found then
				set elem = xmldoc.createElement(pXMLElement) 
				elem.Text = pText
				node.appendChild(elem)
				set elem = nothing
			end if
		next
        
    end function
   

    public function deleteNodes(pXMLElement)

        set itemNodes = xmlDoc.selectNodes("//layout/item/" & pXMLElement)

        for each node in itemNodes
			node.parentNode.removeChild(node) 
        next
        
    end function
        
 
end class 'CTLBDATA
'**** END INCLUDED FILE: classes\_CTLBData.vbs ****


'**** INCLUDED FILE: classes\_CFinder.vbs ****




class CFinder

    private found    

	private sub Class_Initialize()  
        set found = nothing
    end sub  
   
    public function findFilesByFilename(pStartFolder, pFileName, pRecurse) 

		if found is nothing then
			set found = createObject("Scripting.Dictionary")
		end if
		
        set objFolder = gfs.getFolder(pStartFolder)
        set colFiles = objFolder.Files
        for each objFile in colFiles
			if objFile.name = pFilename then
				found.add objFile.path, ""
			end if	
        next

		if pRecurse then
			set colFolders = objFolder.subFolders
			for each fld in colFolders
				set dummy = findFilesByFilename(fld.path, pFileName, true)
			next
		end if

		set findFilesByFilename = found
		
    end function

end class    
    
'**** END INCLUDED FILE: classes\_CFinder.vbs ****


function new_CTLBFolder(pPath)

    set this = new CTLBFolder
    this.path = pPath
    set new_CTLBFolder = this
    
end function 'new_CTLBFolder

class CTLBFolder

    public path    
    
    public function name 
        name = gfs.getBaseName(path)
    end function

    public function folder 
        folder = gfs.getParentFolderName(path)
    end function
    
    public function tlbdata
        tlbdata = gfs.buildPath(path, "tlbdata.xml")
    end function    

    public function setup
        setup = gfs.buildPath(path, "setup.ini")
    end function    

	function isToolbar
	
		isToolbar = false
		if gfs.fileExists(tlbdata) and gfs.fileExists(setup) and not gfs.fileExists(gfs.buildPath(path, "namespace.fld")) then
			set lsetupINI = new CINIFile 
			lsetupINI.load(setup)
			if lsetupINI.findKey("Settings", "toolbarHotkey") > 0 then
				isToolbar = true
			end if	
		end if

		end function
    
	function findToolbar
	
		set tmpTLBFolder = me
		do while not tmpTLBFolder.isToolbar
			set tmpTLBFolder = new_CTLBFolder(tmpTLBFolder.folder)
		loop
		set findToolbar = tmpTLBFolder
		
	end function

	function findVirtualFolders
		
		set vfdict = createObject("Scripting.Dictionary")
		
		set optionsxml = load_CTLBData(F_TLBOPTIONS)
		set toolbars = optionsxml.xmlDoc.selectNodes("//truelaunchbar/toolbars/toolbar")
		for each node in toolbars
			path = node.getAttribute("path")
			if gfs.folderExists(path) then
				set finder = new CFinder
				set foundFiles = finder.findFilesByFilename(path, "namespace.fld", true)
				for each ff in foundFiles.keys
					vfdict.add gfs.getParentFolderName(ff), ""
				next	
			end if
		next
		
		for each node in toolbars
			path = node.getAttribute("path")
			if gfs.folderExists(path) then
				set tbFolder = new_CToolbar(path)
				set setupINI = new CINIFile
				setupINI.load(tbFolder.setup)
				set layouts = setupINI.findSections("layout")
				for each layout in layouts
					layoutPath = setupINI.getKeyValue(layout, "folder")
					if gfs.folderExists(layoutPath) then
						set finder = new CFinder
						set foundFiles = finder.findFilesByFilename(layoutPath, "namespace.fld", true)
						for each ff in foundFiles.keys
							if not vfdict.exists(gfs.getParentFolderName(ff)) then
								vfdict.add gfs.getParentFolderName(ff), ""
							end if
						next	
					end if		
				next
			end if		
		next
		
		set findVirtualFolders = vfdict
		
	end function
	
    public sub create
        gfs.createFolder(path)
    end sub 'create

    public function toString

        toString =  "path: " & path & vbcrlf & _
                    "name: " & name & vbcrlf & _
                    "folder: " & folder & vbcrlf & _
                    "tlbdata: " & tlbdata & vbcrlf & _
                    "setup: " & setup

    end function 'toString

    public sub show
    
        msgbox toString, vbInformation, "CTLBFolder" 
        
    end sub 'show
   
end class    
'**** END INCLUDED FILE: classes\_CTLBFolder.vbs ****

'**** INCLUDED FILE: classes\_CTileImage.vbs ****


'**** INCLUDED FILE: classes\_CPoint.vbs ****
public function toInt(pIn)
    ' safely converts a string to integer
    dim ret
    ret = ""
    for i = 1 to len(pIn)
        if isNumeric(mid(pIn, i, 1)) then
            ret = ret + mid(pIn, i, 1)
        end if   
    next
    toInt = cint(ret)
end function



public function new_CPoint(xy)

    xxy = replace(xy, " ", "")
    point = split(xxy, "x")
    set this = new CPoint
    this.x = toInt(point(0)) ' had issues with CINT here so uses custom toInt instead
    this.y = toInt(point(1))
    
    set new_CPoint = this
    
end function

class CPoint

    public x
    public y

    public function toString

        toString = x & "x" & y
        
    end function
 
    private sub Class_Initialize
        x = 0
        y = 0
    end sub
 
end class
'**** END INCLUDED FILE: classes\_CPoint.vbs ****


class CTileImage

	public tileSize
	
	public iconPath
	public iconSize
	public iconPosition
	public iconOpacity

	public captionFont
	public captionText
	public captionPosition
	public captionShow
	public captionFontSize
	public captionFontColor

	public overlayText
	public overlayPosition
	public overlayShow
	public overlayFontSize
	public overlayFontColor
	public overlayBackgroundColor

	public backgroundImagePath
	public path

	
	public sub setIconSize(pSize)

		if isNumeric(pSize) then
			iconSize = pSize & "x" & pSize
		else
			select case pSize
				case "Full"
					iconSize = "100x100"
				case "Big"
					iconSize = "64x64"				
				case "Original"
					iconSize = "100%"
				case "Small"
					iconSize = "48x48"
				case "Smaller"
					iconSize = "16x16"
				case "Oversized"
					iconSize = "192x192"
				case else 
					iconSize = "32x32"
			end select
		end if		
	end sub
	
    public function create

        dim img 
        dim msgs

		if tileSize = "wide" then
			set dims = new_CPoint("204x100")	
			style = gfs.buildPath(FLD_HOME, "styles\wide.png")
		elseif tileSize = "small" then
			set dims = new_CPoint("48x48")		
			style = gfs.buildPath(FLD_HOME, "styles\small.png")
		else 
			set dims = new_CPoint("100x100")		
			style = gfs.buildPath(FLD_HOME, "styles\medium.png")
		end if
		
		if captionShow = "Never" then
			captionNormal = "mpr:blank"
			captionHover = "mpr:blank"
		elseif captionShow = "On hover" then
			captionNormal = "mpr:blank"
			captionHover = "mpr:caption"
		else
			captionNormal = "mpr:caption"
			captionHover = "mpr:caption"
		end if

		if overlayShow = "Never" then
			overlayNormal = "mpr:blank"
			overlayHover = "mpr:blank"
		elseif overlayShow = "On hover" then
			overlayNormal = "mpr:blank"
			overlayHover = "mpr:overlay"
		else
			overlayNormal = "mpr:overlay"
			overlayHover = "mpr:overlay"
		end if

        set img = createObject("ImageMagickObject.MagickImage.1")

		opacity = iconOpacity / 100

		set bgipf = new_CFile(backgroundImagePath)
		bgipbig = gfs.buildPath(bgipf.folder, bgipf.name & "-big." & bgipf.extension)
		if gfs.fileExists(bgipbig) then
			bgip = bgipbig
		else
			bgip = backgroundImagePath
		end if	

		ao = array("-resize", dims.x - 2 & "x" & dims.y - 2 & "!", "-bordercolor", "none", "-border", "3")
		
'		Win10 errors with blank decode delegate (file type should be PNG) ignore for now	
		on error resume next

        msgs = img.convert(style, "-shave", "2x2", _
						   "-write", "mpr:style", "+delete", _
						   _
						   "-size", dims.toString, "xc:transparent", _ 
						   "-write", "mpr:blank", "+delete", _							   
						   _
						   bgip, "-resize", dims.toString & "!", _
						   "-write", "mpr:color", "+delete", _
						   _
						   "mpr:color", "mpr:style", "-composite",  _	
						   "-write", "mpr:bg", "+delete", _
						   _
						   iconPath, "-bordercolor", "#00000000", "-border", "2", "-trim", "-resize", iconSize, _
						   "-channel", "Alpha", "-evaluate", "Multiply", opacity, _ 						   
						   "-bordercolor", "none", "-border", "8x4", _
						   "-write", "mpr:icon", "+delete", _ 
						   _
						   "-font", captionFont, "-pointsize", captionFontSize, "-fill", captionFontColor, _
						   "-background", "none", "-size", dims.x - 4 & "x", _
						   "-bordercolor", "#00000000", "-border", "8x4", _
						   "-gravity", captionPosition,  "caption:" & captionText, _
						   "-write", "mpr:caption", "+delete", _
						   _
						   "-font", captionFont, "-pointsize", overlayFontSize, "-fill", overlayFontColor, _
						   "-background", "none", "-size", dims.x - 4 & "x", _
						   "-bordercolor", overlayBackgroundColor, "-border", "8x4", _
						   "-gravity", overlayPosition, "caption:" & overlayText, _
						   "-write", "mpr:overlay", "+delete", _ 
						   _
						   "mpr:bg", "mpr:icon", "-gravity", iconPosition, "-composite", _
						   "-write", "mpr:base", _
						   captionNormal, "-gravity", captionPosition, "-composite", _
						   overlayNormal, "-gravity", overlayPosition, "-composite", _
						   "-write", "mpr:normal", _
						   _
						   ao(0), ao(1), ao(2), ao(3), ao(4), ao(5), _
                           "-write", "mpr:active", "+delete", _						   
						   _
						   "mpr:base", _
						   captionHover, "-gravity", captionPosition, "-composite", _
						   overlayHover, "-gravity", overlayPosition, "-composite", _
						   "-bordercolor", "none", "-border", "2", _
						   style, "-gravity", "center", "-composite", _
						   "-write", "mpr:hover", "+delete", _						   
							_
						   "-bordercolor", "none", "-border", "1", _ 
						   "mpr:normal", _
						   "-bordercolor", "none", "-border", "1", _
						   "mpr:active", "mpr:hover", "-append", path)						   

		on error goto 0
		
       	create = true 
                
    end function 'create

	
    public function toString

		toString =  "iconPath: " & iconPath & vbcrlf & _
					"iconSize: " & iconSize & vbcrlf & _
					"iconPosition: " & iconPosition & vbcrlf & _
					"iconOpacity: " & iconOpacity & vbcrlf & _
					"captionText: " & captionText & vbcrlf & _
					"captionPosition: " & captionPosition & vbcrlf & _
					"captionShow: " & captionShow & vbcrlf & _
					"captionFontSize: " & captionFontSize & vbcrlf & _
					"captionFontColor: " & captionFontColor & vbcrlf & _
					"overlayText: " & overlayText & vbcrlf & _
					"overlayPosition: " & overlayPosition & vbcrlf & _
					"overlayShow: " & overlayShow & vbcrlf & _
					"overlayFontSize: " & overlayFontSize & vbcrlf & _
					"overlayFontColor: " & overlayFontColor & vbcrlf & _
					"overlayBackgroundColor: " & overlayBackgroundColor & vbcrlf & _					
					"backgroundImagePath: " & backgroundImagePath & vbcrlf & _
					"path: " & path & vbcrlf
					
    end function 'toString

    public sub show
    
        msgbox toString, vbInformation, "CTileImage" 
        
    end sub 'show

    public sub show2(pTitle)
    
        msgbox toString, vbInformation, pTitle 
        
    end sub 'show
	
	private sub Class_Initialize

		tileSize = "medium"
		iconSize = "normal"
		iconPosition = "center"
		iconOpacity = 100
		iconOffset = "+0+0"
		captionPosition = "southwest"
		caption = "Untitled"
		captionOffset = "+0+0"
		fontColor = "#FFFFFFAA"
		captionOverlay = false
		overlayOnHover = true
	end sub
 
 
end class 


'**** END INCLUDED FILE: classes\_CTileImage.vbs ****

function detectWscriptInstances(pScriptName)

	dim objWMIService, objProcess, colProcess, strComputer
	strComputer = "."

	set objWMIService = GetObject("winmgmts:" _
	& "{impersonationLevel=impersonate}!\\" _
	& strComputer & "\root\cimv2")

	Set colProcess = objWMIService.ExecQuery _
	("Select * from Win32_Process where name = ""wscript.exe"" and commandLine like ""%" & pScriptName & "%""" )

	detectWscriptInstances = colProcess.count
	
end function 'detectWscriptInstances


Function SortArray(ByRef arrShort)
Dim i, j, temp

    For i = UBound(arrShort) - 1 To 0 Step -1
        For j = 0 To i
            If Split(arrShort(j), "_")(2) > Split(arrShort(j + 1), "_")(2) Then
                temp = arrShort(j + 1)
                arrShort(j + 1) = arrShort(j)
                arrShort(j) = temp
            End If
        Next
    Next
    SortArray = arrShort
End Function

'************** MAIN


if detectWscriptInstances(wscript.scriptName) > 1 then wscript.quit

set script = new_CFile(wscript.scriptFullName)
set src = new_CFile(wscript.arguments(0))
set srcFolder = new_CTLBFolder(src.folder)
set srcToolbarFolder = srcFolder.findToolbar
set srcToolbar = new_CToolbar(srcToolbarFolder.path)
set tlbdata = load_CTLBData(srcFolder.tlbdata)
set itemElement = tlbdata.findItemByName(src.filename)  
set tileImage = new CTileImage

'set arrLines = createObject("System.Collections.ArrayList") 
set colorsFolder = gfs.getFolder(FLD_COLORS) 
dim tmpStr
tmpStr = ""
for each colorFile in colorsFolder.files
	if gfs.getExtensionName(colorFile.path) = "png" then
		dim i, fnm
		fnm = colorFile.name
		i = inStrRev(colorFile.name,".")
		if (i > 0) then
			fnm = Mid(colorFile.name, 1, i - 1)
		end if
		tmpStr = tmpStr & "," & fnm
	end if
next

if tmpStr = "" then
	wscript.quit
end if

Colors = mid(tmpStr,2)
splitColors = split(Colors, ",")


set etiXMLDoc = createObject("Microsoft.XMLDOM")
etiXMLDoc.Async = false
etiXMLDoc.setProperty "SelectionLanguage", "XPath"
etiPath = gfs.buildPath(srcFolder.path, "easytileinfo.xml")

lastItem = ""
appendChild = false
if gfs.fileExists(etiPath) then
	etiXMLDoc.load(etiPath)
	lastItem = etiXMLDoc.documentElement.getAttribute("LastItem")
	set elem=etiXMLDoc.selectSingleNode("//item[@name='" & src.fileName & "']")
	if elem is nothing then
		set root=etiXMLDoc.documentElement
		appendChild = true
	end if
else	
	set root = etiXMLDoc.createElement("easytileinfo")
	etiXMLDoc.appendChild(root)
	appendChild = true
end if

if not appendChild then
	TileColor = elem.getAttribute("TileColor")
end if
nextColor = splitColors(0)
for counter = 0 To UBound(splitColors) 
	if TileColor = splitColors(counter) then
		if counter < UBound(splitColors) then
			nextColor = splitColors(counter + 1)
		end if
	end if
next

if src.fileName = lastItem then
	changeColor = true
else
	set lastElem=etiXMLDoc.selectSingleNode("//item[@name='" & lastItem & "']")
	if not lastElem is nothing then
		LastTileColor = lastElem.getAttribute("TileColor")
		if TileColor = LastTileColor then
			changeColor = true
		else
			nextColor = LastTileColor
			changeColor = true
		end if
	end if
end if		

dim currentTileSize	
currentTileSize = ""
if not appendChild then
	currentTileSize = elem.getAttribute("TileSize")
end if	
	
tileImage.tileSize = currentTileSize
if wscript.arguments.named.exists("changecolor") then
	changeColor = true
elseif wscript.arguments.unnamed.count = 2 then
	tileImage.tileSize = wscript.arguments.unnamed.item(1)
	if tileImage.tileSize = currentTileSize then
		changeColor = true
	else changeColor = false
	end if	
end if

select case tileImage.tileSize
	case "small", "medium", "wide"
		'
	case else
		tileImage.tileSize = "medium"
end select
	

if changeColor then
	TileColor = nextColor
end if

if appendChild then
	set elem = etiXMLDoc.createElement("item")
	elem.setAttribute "name", src.fileName
	root.appendChild(elem)
end if

elem.setAttribute "name", src.fileName
elem.setAttribute "TileSize", tileImage.tileSize
elem.setAttribute "TileColor", TileColor
set elem = nothing

set root=etiXMLDoc.documentElement
root.setAttribute "LastItem", src.filename

etiXMLDoc.save etiPath

tlbdata.removeChild itemElement, "altCommand"
tlbdata.addNodes "altCommand", "EasyTileX.changeColor"
tlbdata.save


set image = new_CFile(gfs.buildPath(FLD_HOME, "btnImage.png"))

customIconLocation = ""
customIconLocation = tlbdata.getChildText(itemElement, "IconLocation")
if customIconLocation = "" then
	set sc = gws.createShortcut(src.fullpath)
'	msgbox sc.iconLocation
	if not sc.iconLocation = ",0" then
		customIconLocation = sc.iconLocation
	end if
end if	

dim target
With Createobject("Shell.Application").Namespace(src.folder)
	set target = new_CFile(.Getdetailsof(.Parsename(src.fileName), 196))
end with
'wscript.echo customIconLocation
set iconFile = new_CFile(gfs.buildPath(FLD_ICONS, target.fileName & ".png"))
if customIconLocation = "" then
	if iconFile.exists then
		customIconLocation = iconFile.fullPath
	end if	
end if
'msgbox customIconLocation
iconSrc = ""
if NOT customIconLocation = "" then
	iconSrc = customIconLocation
else
	iconSrc = target.fullPath
end if

set iconSrcFile = new_CResFile(iconSrc)

if instr("exe,dll,ico", iconSrcFile.Extension) then
'	wscript.echo "Extracting..."
	tileImage.iconPath = gfs.buildPath(FLD_HOME, "icon.png")
	return = gws.run("""" & FLD_HOME & "\Quick_Any2Ico.exe"" -res=""" & iconSrc & """ -icon=""" & tileImage.iconPath & """ -formats=256", 0, true)
	if return = 0 then
		gfs.copyFile tileImage.iconPath, iconFile.fullpath 
	else
		gfs.copyFile F_NOICON, tileImage.iconPath, true
	end if
else 'png
	if iconSrcFile.filename = iconSrcFile.fullpath then
		tileImage.iconPath = gfs.buildPath(srcToolbar.icons, iconSrcFile.filename)
	else
		tileImage.iconPath = iconSrcFile.fullpath
	end if
end if	

tileImage.captionText = itemElement.getAttribute("leftText")
if isNull(tileImage.captionText) then
	tileImage.captionText = src.name
end if	


textAlign = itemElement.getAttribute("align")
tileImage.captionPosition = "SouthWest"
if textAlign = 1 then
	tileImage.captionPosition = "SouthEast"
elseif textAlign = 2 then
	tileImage.captionPosition = "South"
end if

captionFontColor = itemElement.getAttribute("textcolor")
if isNull(captionFontColor) then
	captionFontColor = "FFFFFF"
else
	if captionFontColor < 0 then
		captionFontColor = hex(captionFontColor + 2 ^ 31)
	end if
end if
'msgbox captionFontColor

tlbIconSize = itemElement.getAttribute("iconSize")

iconSize = "64"
if tileImage.tileSize = "small" then
	iconSize = "32"
elseif tlbIconSize > 7 then
	iconSize = tlbIconSize
else
	select case tlbIconSize
		case "1"
			iconSize = "Original"
		case "2" 
			iconSize = "Smaller"
		case "3"
			iconSize = "Small"
		case "4"
			iconSize = "Normal"
		case "5"
			iconSize = "Big"
		case "6"
			iconSize = "Full"
		case "7"
			iconSize = "Oversized"				
		case else 
			iconSize = "Normal"
	end select
end if

tileImage.setIconSize(iconSize)

show = itemElement.getAttribute("show")

tileImage.captionShow = "Always"
if show = 1 or tileImage.tileSize = "small" then
	tileImage.captionShow = "Never"		
end if

tileImage.iconOpacity = "100"
if show = 2 then
	tileImage.iconOpacity = "0"
end if

bold = itemElement.getAttribute("bold")
italic = itemElement.getAttribute("italic")

tileImage.captionFont = "Segoe-UI-SemiBold"
if bold = 1 and italic = 1 then
	tileImage.captionFont = "Segoe-UI-Bold-Italic"
elseif bold = 1 then
	tileImage.captionFont = "Segoe-UI-Bold"
elseif italic = 1 then
	tileImage.captionFont = "Segoe-UI-Semibold-Italic"
else
	tileImage.captionFont = "Segoe-UI-Semibold"
end	if


tileImage.path = image.fullpath
tileImage.backgroundImagePath = gfs.buildPath(FLD_COLORS, tileColor & ".png")
tileImage.iconPosition = "Center"
'tileImage.iconOpacity = "100"
tileImage.captionFontColor = "#" & captionFontColor
'tileImage.captionPosition = "SouthWest"
'tileImage.captionShow = "Always"
tileImage.captionFontSize = "12"
tileImage.overlayText = "Overlay"
tileImage.overlayBackgroundColor = "Black"
tileImage.overlayPosition = "South"
tileImage.overlayShow = "Never"
tileImage.overlayFontSize = "16"
'tileImage.tileSize = "Medium"

ret = tileImage.create


if src.exists then
	if gfs.fileExists(srcFolder.tlbdata) then
		setImage srcFolder.tlbdata, src.filename, tileImage.path
	else	
		set virtualFolders = srcFolder.findVirtualFolders
		for each vf in virtualFolders.keys
			set srcFolder = new_CTLBFolder(vf)
			setImage srcFolder.tlbdata, src.filename, tileImage.path
		next
	end if
	
end if



'gws.sendkeys "{ESC}"
gws.sendkeys HK_REFRESH


sub setImage(ptlbdata, pItemName, pImagePath)

	if gfs.fileExists(ptlbdata) then

		set tlbFolder = new_CTLBFolder(gfs.getParentFolderName(ptlbdata))
		set image = new_CFile(pImagePath)
		set srcToolbarFolder = tlbFolder.findToolbar

		set srcToolbar = new_CToolbar(srcToolbarFolder.path)

		set dstImage = new_CFile(gfs.buildPath(srcToolbar.btnImages, src.name & ".png"))	

		if not gfs.folderExists(dstImage.folder) then
			if not gfs.folderExists(dstImage.parentFolder) then
				gfs.createFolder(dstImage.parentFolder)
			end if
			gfs.createFolder(dstImage.folder)
		end if

		gfs.copyFile image.fullPath, dstImage.fullPath, true
		set tlbdata = load_CTLBData(tlbFolder.tlbdata)
		set itemElement=tlbdata.findItemByName(pItemName)  
		itemElement.setAttribute "ImagePath", dstImage.fileName
		tlbdata.save
		
	end if		
	
end sub
